@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION @ISA);
-$VERSION = '0.07';
+$VERSION = '0.08';
 
 #--------------------------------------------------------------------------
 
@@ -111,7 +111,8 @@ sub search {
   	# The Book page
     my $html = $mech->content();
 	return $self->handler("Failed to find that book on the WHSmith website. [$isbn]")
-		if($html =~ m!Sorry, no products were found!si);
+		if($html =~ m!Sorry, no products were found!si ||
+           $html !~ m!</html>!si);  # sometimes the WHSmith site only sends back a small portion of the page :(
 
     my $url = $mech->uri();
 	return $self->handler("Failed to find that book on the WHSmith website. [$isbn]")
@@ -235,7 +236,7 @@ be forthcoming, please feel free to (politely) remind me.
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright (C) 2010-2014 Barbie for Miss Barbell Productions
+  Copyright (C) 2010-2015 Barbie for Miss Barbell Productions
 
   This distribution is free software; you can redistribute it and/or
   modify it under the Artistic Licence v2.
